pub struct Snapshot(pub Digest);Tuple Fields
0: DigestTrait Implementations
Sourceimpl BorshDeserialize for Snapshot
impl BorshDeserialize for Snapshot
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Snapshot, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Snapshot
impl BorshSerialize for Snapshot
impl Eq for Snapshot
Sourceimpl HasBorshSchema for Snapshot
impl HasBorshSchema for Snapshot
fn borsh_schema() -> BorshSchema
Sourceimpl Ord for Snapshot
impl Ord for Snapshot
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Snapshot
impl PartialOrd for Snapshot
impl StructuralPartialEq for Snapshot